ConstOverflowingSub

Trait ConstOverflowingSub 

pub trait ConstOverflowingSub: Sized + Sub<Output = Self> {
    // Required method
    fn overflowing_sub(&self, v: &Self) -> (Self, bool);
}
Const-compatible overflowing subtraction.

Required Methods

fn overflowing_sub(&self, v: &Self) -> (Self, bool)

Returns a tuple of the difference along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl ConstOverflowingSub for u8

Source

fn overflowing_sub(&self, v: &Self) -> (Self, bool)

Source

impl ConstOverflowingSub for u16

Source

fn overflowing_sub(&self, v: &Self) -> (Self, bool)

Source

impl ConstOverflowingSub for u32

Source

fn overflowing_sub(&self, v: &Self) -> (Self, bool)

Source

impl ConstOverflowingSub for u64

Source

fn overflowing_sub(&self, v: &Self) -> (Self, bool)

Source

impl ConstOverflowingSub for u128

Source

fn overflowing_sub(&self, v: &Self) -> (Self, bool)

Implementors

Source

impl<T: ConstMachineWord + MachineWord, const N: usize> ConstOverflowingSub for FixedUInt<T, N>