pub trait ConstDivCeil:
Sized
+ ConstZero
+ ConstOne
+ ConstCheckedAdd {
// Required methods
fn div_ceil(self, rhs: Self) -> Self;
fn checked_div_ceil(self, rhs: Self) -> Option<Self>;
}Expand description
Const-compatible ceiling division.
Returns the smallest integer greater than or equal to the exact quotient.
Required Methods
Sourcefn checked_div_ceil(self, rhs: Self) -> Option<Self>
fn checked_div_ceil(self, rhs: Self) -> Option<Self>
Calculates the quotient of self and rhs, rounding up.
Returns None if rhs is zero.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.