FixedUInt

Struct FixedUInt 

pub struct FixedUInt<T, const N: usize>
where T: MachineWord,
{ /* private fields */ }
Fixed-size unsigned integer, represented by array of N words of builtin unsigned type T

Implementations

Source

impl<T: MachineWord, const N: usize> FixedUInt<T, N>

pub fn new() -> FixedUInt<T, N>

Creates and zero-initializes a FixedUInt.

pub fn words(&self) -> &[T; N]

Returns the underlying array.

pub fn bit_length(&self) -> u32

Returns number of used bits.

pub fn div_rem(&self, divisor: &Self) -> (Self, Self)

Performs a division, returning both the quotient and remainder in a tuple.

Source

impl<T: MachineWord, const N: usize> FixedUInt<T, N>

pub fn from_le_bytes(bytes: &[u8]) -> Self

Create a little-endian integer value from its representation as a byte array in little endian.

pub fn from_be_bytes(bytes: &[u8]) -> Self

Create a big-endian integer value from its representation as a byte array in big endian.

Source

impl<T: MachineWord, const N: usize> FixedUInt<T, N>

pub fn to_le_bytes<'a>( &self, output_buffer: &'a mut [u8], ) -> Result<&'a [u8], bool>

Converts the FixedUInt into a little-endian byte array.

pub fn to_be_bytes<'a>( &self, output_buffer: &'a mut [u8], ) -> Result<&'a [u8], bool>

Converts the FixedUInt into a big-endian byte array.

pub fn to_hex_str<'a>(&self, result: &'a mut [u8]) -> Result<&'a str, Error>

Converts to hex string, given a buffer. CAVEAT: This method removes any leading zeroes

pub fn to_radix_str<'a>( &self, result: &'a mut [u8], radix: u8, ) -> Result<&'a str, Error>

Converts to decimal string, given a buffer. CAVEAT: This method removes any leading zeroes